@@ -71,6 +71,8 @@ class CommandParser:
 
         self.add_subcommand_parser(subparsers, "delete", "drop a queue")
 
+        self.add_subparser(subparsers, "delete_all", "delete all queues")
+
         self.add_subparser(subparsers, "stats", "queue status")
 
         self.add_subparser(subparsers, "list", "queue list")
@@ -190,7 +192,15 @@ class CommandLine:
         self.client.add(self.args.queue, data)
 
     def cmd_delete(self):
-        print(self.client.delete(self.args.queue))
+        if self.client.delete(self.args.queue):
+            print("deleted: %s" % self.args.queue)
+
+    def cmd_delete_all(self):
+        server, stats = self.client.stats()
+        queues = stats["queues"]
+        for queue in queues.keys():
+            self.client.delete(queue)
+            print("deleted: %s" % queue)
 
     def cmd_stats(self):
         server, stats = self.client.stats()
@@ -222,6 +232,8 @@ class CommandLine:
 
 
 def main(argv=sys.argv, client_class=kestrel.Client):
+    if len(argv) == 1:
+        argv.append("--help")
     parser = CommandParser(argv)
     if not parser.parse_exit:
         CommandLine.execute(parser.args, client_class)
